Python: module ichorORM.objs

ichorORM.objs | index

`Copyright (c) 2016-2018 Timothy Savannah
Licensed under the terms of the Lesser GNU Lesser General Public License version 2.1
license can be found at https://raw.githubusercontent.com/kata198/ichorORM/master/LICENSE
objs - Various utility classes`

Classes
`` |  | builtins.dict(builtins.object) DictObj builtins.object IgnoreParameterType
class DictObj(builtins.dict)
`` | `DictObj - A dictionary that supports dot-access the same as array-access for reads, but not for writes.`
| Method resolution order: DictObj builtins.dict builtins.object Methods defined here: __getattribute__(self, attrName) `__getattribute__ - Called on dot-access. Searches if a key exists within this dict with the given name, falling back to object-access` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` Methods inherited from builtins.dict: __contains__(self, key, /) `True if D has a key k, else False.` __delitem__(self, key, /) `Delete self[key].` __eq__(self, value, /) `Return self==value.` __ge__(self, value, /) `Return self>=value.` __getitem__(...) `x.__getitem__(y) <==> x[y]` __gt__(self, value, /) `Return self>value.` __init__(self, /, *args, **kwargs) `Initialize self. See help(type(self)) for accurate signature.` __iter__(self, /) `Implement iter(self).` __le__(self, value, /) `Return self<=value.` __len__(self, /) `Return len(self).` __lt__(self, value, /) `Return self<value.` __ne__(self, value, /) `Return self!=value.` __new__(*args, **kwargs) from builtins.type `Create and return a new object. See help(type) for accurate signature.` __repr__(self, /) `Return repr(self).` __setitem__(self, key, value, /) `Set self[key] to value.` __sizeof__(...) `D.__sizeof__() -> size of D in memory, in bytes` clear(...) `D.clear() -> None. Remove all items from D.` copy(...) `D.copy() -> a shallow copy of D` fromkeys(iterable, value=None, /) from builtins.type `Returns a new dict with keys from iterable and values equal to value.` get(...) `D.get(k[,d]) -> D[k] if k in D, else d. d defaults to None.` items(...) `D.items() -> a set-like object providing a view on D's items` keys(...) `D.keys() -> a set-like object providing a view on D's keys` pop(...) `D.pop(k[,d]) -> v, remove specified key and return the corresponding value. If key is not found, d is returned if given, otherwise KeyError is raised` popitem(...) `D.popitem() -> (k, v), remove and return some (key, value) pair as a 2-tuple; but raise KeyError if D is empty.` setdefault(...) `D.setdefault(k[,d]) -> D.get(k,d), also set D[k]=d if k not in D` update(...) `D.update([E, ]**F) -> None. Update D from dict/iterable E and F. If E is present and has a .keys() method, then does: for k in E: D[k] = E[k] If E is present and lacks a .keys() method, then does: for k, v in E: D[k] = v In either case, this is followed by: for k in F: D[k] = F[k]` values(...) `D.values() -> an object providing a view on D's values` Data and other attributes inherited from builtins.dict: __hash__ = None
class IgnoreParameterType(builtins.object)
`` | `IgnoreParameterType - A special type for a singleton, #IgnoreParameter, which can be used as a default "ignore this parameter" when None/False are valid values. Because it is intended as a singleton type, comparisons are such that IgnoreParameterType only equals other IgnoreParameterType objects (or the type itself)`
| Methods defined here: __bool__(self) `__bool__ - Typecast to a boolean. Returns False. @return <bool> - False` __eq__(self, other) `__eq__ - Test equality. Comparing against any other IgnoreParameterType object or the type itself is True, anything else is False. @param other <???> - The variable being compared @return <bool> - True if same type or is the type itself, otherwise False` __ne__(self, other) `__ne__ - Test inequality. @see IgnoreParameterType.__eq__` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` Data and other attributes defined here: __hash__ = None

Data
`` |  | IgnoreParameter = <ichorORM.objs.IgnoreParameterType object> UseGlobalSetting = <ichorORM.objs.IgnoreParameterType object> __all__ = ('DictObj', 'IgnoreParameterType', 'IgnoreParameter', 'UseGlobalSetting')